//+------------------------------------------------------------------+
//|                                        CounterSwing OpenHiLo.mq4 |
//|                                             2008.06.20 SwingMan |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright " 2008.06.20 SwingMan"
#property link      ""

#property indicator_separate_window

#property  indicator_buffers 6
#property  indicator_color1  Green     // Diff OpenHigh
#property  indicator_color2  OrangeRed  // Diff OpenLow
#property  indicator_color3  Blue     // Med Diff High
#property  indicator_color4  Aqua       // Dev Diff
#property  indicator_color5  Red     // Med Diff Low
#property  indicator_color6  Magenta       // Dev Diff

#property  indicator_level1 0
#property  indicator_levelcolor Gray
#property  indicator_levelstyle STYLE_DOT

//---- input parameters ---------------------------------------------
extern int Period_Statistic = 10;
extern int Period_ATR = 40;
//-------------------------------------------------------------------

//---- indicator buffers
double AvTrueRange[];
double DiffOpenHigh[], DiffOpenLow[];
double MedDifferencesOHigh[], DevDifferencesOHigh[];
double MedDifferencesOLow[], DevDifferencesOLow[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//   ArraySetAsSeries(PivotLine,true);
//   ArraySetAsSeries(BalanceLine,true);
   ArraySetAsSeries(AvTrueRange,true);   
   
//---- indicator buffers mapping
   SetIndexBuffer(0,DiffOpenHigh);
   SetIndexBuffer(1,DiffOpenLow);
   SetIndexBuffer(2,MedDifferencesOHigh);   
   SetIndexBuffer(3,DevDifferencesOHigh);
   SetIndexBuffer(4,MedDifferencesOLow);   
   SetIndexBuffer(5,DevDifferencesOLow);

   //---- drawing settings
   SetIndexStyle(0,DRAW_HISTOGRAM,0,2);  // Pivot   
   SetIndexStyle(1,DRAW_HISTOGRAM,0,2);  // Pivot   
   SetIndexStyle(2,DRAW_LINE,0,2);  // Med
   SetIndexStyle(3,DRAW_LINE,0,1);  // Dev
   SetIndexStyle(4,DRAW_LINE,0,2);  // Med
   SetIndexStyle(5,DRAW_LINE,0,1);  // Dev   
      
   IndicatorDigits(Digits);
   
   SetIndexDrawBegin(0,Period_Statistic);
   SetIndexDrawBegin(1,Period_Statistic);
   SetIndexDrawBegin(2,Period_Statistic);
   SetIndexDrawBegin(3,Period_Statistic);
   SetIndexDrawBegin(4,Period_Statistic);
   SetIndexDrawBegin(5,Period_Statistic);   

//---- name for DataWindow and indicator subwindow label
   string sWindowsName = "CounterSwing OpenHiLo";
   IndicatorShortName(sWindowsName);
   //Comment(sWindowsName);
   
   SetIndexLabel(0,"Diff OpenHigh%"); 
   SetIndexLabel(1,"Diff OpenLow%"); 
   SetIndexLabel(2,"Med DiffOHigh%");   
   SetIndexLabel(3,"Dev DiffOHigh%");   
   SetIndexLabel(4,"Med DiffOLow%");   
   SetIndexLabel(5,"Dev DiffOLow%");      
//---- initialization done
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {  
   return(0);
  }
  
    
//+------------------------------------------------------------------+
//| START                                                            |
//+------------------------------------------------------------------+
int start()
  {
   ArrayResize(AvTrueRange,Bars);   
   
   int counted_bars = IndicatorCounted();  
   int i;
//---- check for possible errors   
   if (counted_bars<0) return(-1);
   if(Bars<=10) return(0);
//---- last counted bar will be recounted
   if (counted_bars>0) counted_bars--;  
   int limit=Bars-counted_bars;   

   //---- PIVOTS------------------------------------------------------
   //-- Pivot Line
   for(i=0; i<limit; i++) {      
      AvTrueRange[i] = iATR(NULL,0,Period_ATR,i+1);
   }   
   
   //---- DIFFERENCE PIVOT-CLOSE -------------------------------------
   for(i=0; i<limit; i++) {      
      if (AvTrueRange[i] > 0) {        
         double diffOpenHigh = 100*(iHigh(NULL,0,i) - iOpen(NULL,0,i)) / AvTrueRange[i];
         double diffOpenLow  = 100*(iLow(NULL,0,i) - iOpen(NULL,0,i)) / AvTrueRange[i];
         
         if (MathAbs(diffOpenHigh) > MathAbs(diffOpenLow)) {
            DiffOpenHigh[i] = MathAbs(diffOpenHigh);
            DiffOpenLow[i]  = -MathAbs(diffOpenLow);
         } else {
            DiffOpenHigh[i] = MathAbs(diffOpenLow);
            DiffOpenLow[i]  = -MathAbs(diffOpenHigh);
         }               
      }
   }
   
   for(i=0; i<limit; i++) {      
      MedDifferencesOHigh[i] = iMAOnArray(DiffOpenHigh,0,Period_Statistic,1,MODE_SMA,i);
      DevDifferencesOHigh[i] = iStdDevOnArray(DiffOpenHigh,0,Period_Statistic,1,MODE_SMA,i);
      MedDifferencesOLow[i] = iMAOnArray(DiffOpenLow,0,Period_Statistic,1,MODE_SMA,i);
      DevDifferencesOLow[i] = -iStdDevOnArray(DiffOpenLow,0,Period_Statistic,1,MODE_SMA,i);      
   }      

//---- done
   return(0);
}  
//+------------------------------------------------------------------+


